scipy.maxentropy.maxentutils
============================

.. automodule:: scipy.maxentropy.maxentutils

   
   
   .. rubric:: Functions

   .. autosummary::
   
      arrayexp
      arrayexpcomplex
      asarray
      columnmeans
      columnvariances
      densefeaturematrix
      densefeatures
      dotprod
      empty
      flatten
      innerprod
      innerprodtranspose
      logsumexp
      logsumexp_naive
      robustlog
      rowmeans
      sample_wr
      sparsefeaturematrix
      sparsefeatures
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      ndarray
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      DivergenceError
   
   